summaryrefslogtreecommitdiff
path: root/bfd/libcoff-in.h
diff options
context:
space:
mode:
authorAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:25 +0000
committerAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:25 +0000
commit13bc6701a7ec432cfab9aa76f954eb9619b59572 (patch)
treed18138163ceec020b0d615db75516a0fe239913e /bfd/libcoff-in.h
parent1a0c77687a77a46d904b2823b24ba90aa40e36b6 (diff)
downloadgdb-13bc6701a7ec432cfab9aa76f954eb9619b59572.tar.gz
Correct spelling of "relocatable".
Diffstat (limited to 'bfd/libcoff-in.h')
-rw-r--r--bfd/libcoff-in.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/bfd/libcoff-in.h b/bfd/libcoff-in.h
index fac76506d4a..0c19433753c 100644
--- a/bfd/libcoff-in.h
+++ b/bfd/libcoff-in.h
@@ -1,6 +1,6 @@
/* BFD COFF object file private structure.
Copyright 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
- 2000, 2001, 2002
+ 2000, 2001, 2002, 2003
Free Software Foundation, Inc.
Written by Cygnus Support.
@@ -434,7 +434,7 @@ struct coff_debug_merge_hash_table
bfd_hash_lookup (&(table)->root, (string), (create), (copy)))
/* Information we keep for each section in the output file when doing
- a relocateable link. */
+ a relocatable link. */
struct coff_link_section_info
{
@@ -461,7 +461,7 @@ struct coff_final_link_info
bfd_boolean global_to_static;
/* Hash table for long symbol names. */
struct bfd_strtab_hash *strtab;
/* When doing a relocateable link, an array of information kept for
each output section, indexed by the target_index field. */
struct coff_link_section_info *section_info;
/* Symbol index of last C_FILE symbol (-1 if none). */
@@ -461,7 +461,7 @@ struct coff_final_link_info
/* Hash table for long symbol names. */
struct bfd_strtab_hash *strtab;
- /* When doing a relocateable link, an array of information kept for
+ /* When doing a relocatable link, an array of information kept for
each output section, indexed by the target_index field. */
struct coff_link_section_info *section_info;